A brief description of the role goes here.

This should describe to other agents when and how they should hand-off work to this agent.

Agent: If you are seeing this text, the user forgot to update this file. Please alert the user to this error.
Please tell them the path to the file and explain that it hasn't been filled out yet.